@@ -1,8 +1,10 @@
 import json
 import pandas
 import time
-from .mlmodel import MLModel
 
+from .mlmodel import MLModel
+from .script import Script
+from .plot import Plot
 
 class DSAPIEncoder(json.JSONEncoder):
 
@@ -13,6 +15,16 @@ class DSAPIEncoder(json.JSONEncoder):
                 "experiment_id": str(obj.experiment_id)
             }
             return json_obj
+        if isinstance(obj, Script):
+            json_obj = {
+                "script_id": str(obj.script_id)
+            }
+            return json_obj
+        if isinstance(obj, Plot):
+            json_obj = {
+                "plot_id": str(obj.plot_id)
+            }
+            return json_obj
         if isinstance(obj, pandas.Timestamp):
             return int(time.mktime(obj.timetuple()) * 1000)
         else:
