@@ -26,7 +26,8 @@ class Execution:
         self.result_dataframe = None
 
     def append_plot(self, figure, name="Unkwown"):
-        plot = Plot(name)
+        plot = Plot()
+        plot.name = name
         plot.experiment_id = self.experiment_id
         plot.figure = figure
         self.plots.append(plot)
