@@ -34,11 +34,9 @@ class Script:
     def copy(self, myfunction):
         self.function = Function()
         self.function.code = myfunction.__code__
-        self.function.globals = myfunction.__globals__
 
 
 class Function:
 
     def __init__(self):
         self.code = None
-        self.globals = None
